/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.service.admin;

import junit.framework.Assert;

import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.test.context.transaction.AfterTransaction;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.ParliamentChart;
import com.hack23.cia.model.sweden.impl.PoliticalParty;
import com.hack23.cia.service.dao.AgencyDAO;
import com.hack23.cia.service.impl.admin.LoaderService;
import com.hack23.cia.service.impl.common.ParliamentService;
import com.hack23.cia.testfoundation.AbstractFunctionalIntegrationTransactionalTest;

/**
 * The Class LoaderServiceImplGeneratePoliticalPartyChartsSuccessFullTest.
 */
public class LoaderServiceImplGeneratePoliticalPartyChartsSuccessFullTest extends
        AbstractFunctionalIntegrationTransactionalTest {

    /** The agency dao. */
    @Autowired
    @Qualifier("agencyDAO")
    private AgencyDAO agencyDAO;

    /** The loader service. */
    @Autowired
    @Qualifier("loaderService")
    private LoaderService loaderService;
    
    /** The parliament service. */
    @Autowired
    @Qualifier("parliamentService")
    private ParliamentService parliamentService;
    
    /** The political party. */
    private PoliticalParty politicalParty;
    
    
    
    /**
     * Instantiates a new loader service impl generate political party charts success full test.
     */
    public LoaderServiceImplGeneratePoliticalPartyChartsSuccessFullTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Generate charts succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void generateChartsSucceeds() throws Exception {
    	this.politicalParty= parliamentService.getPoliticalParties().get(0);
    	loaderService.generatePoliticalPartyCharts(politicalParty.getId());    	
    }

    /**
     * Setup database pre condition.
     *
     * @throws Exception the exception
     */
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
    	this.cleanOutOldTestData();
    }

    /**
     * Verify database post condition.
     *
     * @throws Exception the exception
     */
    @AfterTransaction
    public void verifyDatabasePostCondition() throws Exception {
    	Agency agency = agencyDAO.load(1L);
    	Language language = agency.getLanguages().iterator().next();
    			Assert.assertNotNull("Chart Missing:",parliamentService.getGraph(ParliamentChart.Summary,politicalParty,language));        		
        		Assert.assertNotNull("Chart Missing:",parliamentService.getGraph(ParliamentChart.Outcome,politicalParty,language));
        		Assert.assertNotNull("Chart Missing:",parliamentService.getGraph(ParliamentChart.ProffessionalBehavior,politicalParty,language));
        		Assert.assertNotNull("Chart Missing:",parliamentService.getGraph(ParliamentChart.PoliticalPartyBehavior,politicalParty,language));
    }
}
