/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.service.application;

import junit.framework.Assert;

import org.dbunit.database.QueryDataSet;
import org.junit.Test;
import org.springframework.test.context.transaction.AfterTransaction;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.functionalintegrationtest.scenarios.service.common.AbstractServiceRequestFunctionalIntegrationTest;
import com.hack23.cia.functionalintegrationtest.scenarios.service.common.TestRequestFactory;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.model.application.impl.common.User.UserRole;
import com.hack23.cia.model.application.impl.user.ApplicationActionEvent;
import com.hack23.cia.service.api.application.ApplicationRequest;
import com.hack23.cia.service.api.application.ApplicationRequest.HeaderAttributeKey;
import com.hack23.cia.service.api.common.ServiceResponse.ServiceResult;

/**
 * The Class ApplicationRequestSuccessFullTest.
 */
public class ApplicationRequestSuccessFullTest extends
    AbstractServiceRequestFunctionalIntegrationTest {
    
    /**
     * Instantiates a new application request success full test.
     */
    public ApplicationRequestSuccessFullTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Application request succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void applicationRequestSucceeds() throws Exception {
        ApplicationRequest applicationRequest = TestRequestFactory
                .createApplicationRequestSwedishUser();

        serviceResponse = this.applicationManager.service(applicationRequest);
        Assert.assertEquals(ServiceResult.SUCCESS, serviceResponse.getResult());        
       
        responseUserSession = serviceResponse.getUserSessionDTO().getUserSession();        
        Assert.assertEquals(UserRole.ANYNOMOUS, responseUserSession.getUser().getUserRole());
        Assert.assertEquals(applicationRequest.getHeaderAttribute(HeaderAttributeKey.HEADER_HOST),responseUserSession.getServerHost());
        Assert.assertEquals(applicationRequest.getHeaderAttribute(HeaderAttributeKey.CLIENT_INFO_HOST),responseUserSession.getClientHost());
        Assert.assertEquals(applicationRequest.getHeaderAttribute(HeaderAttributeKey.HEADER_COOKIE),responseUserSession.getSessionId());
        Assert.assertEquals(true,responseUserSession.getActive());
        Assert.assertNotNull(responseUserSession.getCreatedAt());        
        
        Agency agency = responseUserSession.getPortal().getAgency();
        Assert.assertEquals("Discordian Propaganda & Communications Unit",agency.getName());
 
        Portal portal = responseUserSession.getPortal();
        Assert.assertEquals("Citizen Intelligence Agency", portal.getName());
        Assert.assertEquals("localhost", portal.getMatchesUrl());
        
        Language language = responseUserSession.getLanguage();
        Assert.assertEquals("Swedish", language.getName());
        Assert.assertEquals(Language.SWEDISH_LANGUAGE_CODE, language.getShortCode());        
        
        ApplicationActionEvent event = (ApplicationActionEvent) responseUserSession.getEvents().iterator().next();
        Assert.assertNotNull(event.getCreatedDate());
        Assert.assertNotNull(event.getExecutionTime());
        
        //Max service executionTime 1000ms
        Assert.assertTrue(1000L >= event.getExecutionTime().longValue());
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.service.common.AbstractServiceRequestFunctionalIntegrationTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.service.common.AbstractServiceRequestFunctionalIntegrationTest#verifyDatabasePostCondition()
     */
    @Override
    @AfterTransaction
    public void verifyDatabasePostCondition() throws Exception {
        QueryDataSet queryDataset = getQueryDataset();
        queryDataset.addTable("UserSession",
                "SELECT * FROM UserSession where id="
                        + responseUserSession.getId());
        Assert.assertEquals(1, queryDataset.getTable("UserSession")
                .getRowCount());
       
        Assert.assertEquals(responseUserSession.getSessionId(),queryDataset.getTable("UserSession").getValue(0,
        "sessionId"));
        Assert.assertEquals(responseUserSession.getServerHost(),queryDataset.getTable("UserSession").getValue(0,
        "serverHost"));
        Assert.assertEquals(responseUserSession.getClientHost(),queryDataset.getTable("UserSession").getValue(0,
        "clientHost"));
        Assert.assertNotNull(queryDataset.getTable("UserSession").getValue(0,
        "createdAt"));
        Assert.assertEquals(true,queryDataset.getTable("UserSession").getValue(0,
        "active"));        

        Assert.assertEquals(responseUserSession.getPortal().getId().toString(),queryDataset.getTable("UserSession").getValue(0,
        "portal_id").toString());
        Assert.assertEquals(responseUserSession.getLanguage().getId().toString(),queryDataset.getTable("UserSession").getValue(0,
        "language_id").toString());
        Assert.assertEquals(responseUserSession.getUser().getId().toString(),queryDataset.getTable("UserSession").getValue(0,
        "user_id").toString());

        
        queryDataset = getQueryDataset();
        queryDataset.addTable("AbstractActionEvent",
                "SELECT * FROM AbstractActionEvent where userSession_id="
                        + responseUserSession.getId());
        Assert.assertEquals(1, queryDataset.getTable("AbstractActionEvent")
                .getRowCount());
        Assert.assertEquals("ApplicationActionEvent", queryDataset.getTable(
                "AbstractActionEvent").getValue(0, "actioneventtype"));

        Assert.assertNotNull(queryDataset.getTable(
        "AbstractActionEvent").getValue(0, "createdDate"));
        Assert.assertNotNull(queryDataset.getTable(
        "AbstractActionEvent").getValue(0, "executionTime"));
    }
}
