/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.service.impl.agent.sweden;

import junit.framework.Assert;

import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.test.context.transaction.AfterTransaction;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.model.sweden.impl.RegisterInformation;
import com.hack23.cia.service.impl.agent.sweden.ParliamentMemberRegisterAgent;
import com.hack23.cia.testfoundation.AbstractFunctionalIntegrationTransactionalTest;

/**
 * The Class ParliamentMemberRegisterAgentSuccessFullTest.
 */
public class ParliamentMemberRegisterAgentSuccessFullTest extends
        AbstractFunctionalIntegrationTransactionalTest {

    /** The parliament member register agent. */
    @Autowired
    @Qualifier("parliamentMemberRegisterAgent")
    private ParliamentMemberRegisterAgent parliamentMemberRegisterAgent;

    /**
     * Instantiates a new parliament member register agent success full test.
     */
    public ParliamentMemberRegisterAgentSuccessFullTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Lookup register information succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void lookupRegisterInformationSucceeds() throws Exception {
        ParliamentMember parliamentMember = new ParliamentMember();
        parliamentMember.setName("Sahlin, Mona");
        parliamentMember.setParty("s");
        RegisterInformation registerInformation = parliamentMemberRegisterAgent.lookupRegisterInformation(parliamentMember);
        
        Assert.assertNotNull(registerInformation);
        //Mona Sahlin, have oddly enough no other loyalties declared.        
        Assert.assertEquals("X",registerInformation.getNothingDeclared());
        
        Assert.assertNotNull(registerInformation.getElectoralArea());
        Assert.assertNotNull(registerInformation.getAgreements());
        Assert.assertNotNull(registerInformation.getAllowances());
        Assert.assertNotNull(registerInformation.getHouses());
        Assert.assertNotNull(registerInformation.getIncomeActivity());
        Assert.assertNotNull(registerInformation.getPublicRoles());
        Assert.assertNotNull(registerInformation.getRoles());
        Assert.assertNotNull(registerInformation.getStocks());        
    }

    /**
     * Setup database pre condition.
     *
     * @throws Exception the exception
     */
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
    }

    /**
     * Verify database post condition.
     *
     * @throws Exception the exception
     */
    @AfterTransaction
    public void verifyDatabasePostCondition() throws Exception {
    }
}
