/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.admin;

import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.transaction.PlatformTransactionManager;

import com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest;
import com.hack23.cia.model.application.impl.admin.AgencyActionEvent;
import com.hack23.cia.model.application.impl.admin.LanguageAgencyActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.service.api.admin.AgencyRequest;
import com.hack23.cia.service.api.admin.AgencyResponse;
import com.hack23.cia.service.api.admin.LanguageRequest;
import com.hack23.cia.service.api.admin.LanguageResponse;
import com.hack23.cia.service.impl.admin.AdminService;

/**
 * The Class AbstractFunctionalAdminActionTest.
 */
public abstract class AbstractFunctionalAdminActionTest extends
        AbstractFunctionalActionWithoutViewFactoryTest {

    /** The admin service. */
    @Autowired
    @Qualifier("adminService")
    protected AdminService adminService;
    
    /** The transaction manager. */
    @Autowired
    @Qualifier("transactionManager")
    protected PlatformTransactionManager transactionManager;

    /**
     * Creates the language.
     *
     * @return the language
     */
    protected final Language createLanguage() {
        Long agencyId = this.adminService.loadAgency().getId();
        AgencyRequest agencyRequest = new AgencyRequest(userSession.getId(), AgencyActionEvent.Operation.AddLanguage, agencyId);
        AgencyResponse agencyResponse = (AgencyResponse) this.applicationManager.service(
                agencyRequest);
        Set<Language> languages = agencyResponse.getAgency().getLanguages();
        return findLanguageByName("Default", languages);
    }

    /**
     * Creates the language content.
     *
     * @param agency the agency
     * @param language the language
     * @return the language content
     */
    protected final LanguageContent createLanguageContent(final Agency agency,final Language language) {
        LanguageRequest languageRequest = new LanguageRequest(userSession.getId(), LanguageAgencyActionEvent.Operation.AddLanguageContent, agency, language);
        LanguageResponse languageResponse = (LanguageResponse) this.applicationManager.service(languageRequest);
        return languageResponse.getLanguageContent();
    }
    
    
    
    /**
     * Creates the portal.
     *
     * @return the portal
     */
    protected final Portal createPortal() {
        Long agencyId = this.adminService.loadAgency().getId();
        AgencyRequest agencyRequest = new AgencyRequest(userSession.getId(), AgencyActionEvent.Operation.AddPortal, agencyId);
        AgencyResponse agencyResponse = (AgencyResponse) this.applicationManager.service(
                agencyRequest);
        Set<Portal> portals = agencyResponse.getAgency().getPortals();
        return findPortalByName("Default portal", portals);
    }
    
    
    /**
     * Find language by name.
     *
     * @param name the name
     * @param languages the languages
     * @return the language
     */
    private final Language findLanguageByName(String name,Set<Language> languages) {
        for (Language language : languages) {
            if (name.trim().equalsIgnoreCase(language.getName().trim())) {
                return language;
            }
        }
        return null;
    }

    /**
     * Find portal by name.
     *
     * @param name the name
     * @param portals the portals
     * @return the portal
     */
    private final Portal findPortalByName(String name,Set<Portal> portals) {
        for (Portal portal : portals) {
            if (name.trim().equalsIgnoreCase(portal.getName().trim())) {
                return portal;
            }
        }
        return null;
    }

    
    
    /**
     * Prepare logged in admin user.
     *
     * @throws Exception the exception
     */
    protected final void prepareLoggedInAdminUser() throws Exception {
        prepareLoggedInAsUser("sysop", "equalrites");
    }

}
