/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.admin;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.test.context.transaction.AfterTransaction;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.application.impl.admin.AgencyActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.service.dao.AgencyDAO;
import com.hack23.cia.web.action.admin.AgencyAction;
import com.hack23.cia.web.viewfactory.api.admin.AgencyModelAndView;

/**
 * The Class AgencyActionAddLanguageSuccessTest.
 */
public class AgencyActionAddLanguageSuccessTest extends
        AbstractFunctionalAdminActionTest {

    /** The agency dao. */
    @Autowired
    @Qualifier("agencyDAO")
    private AgencyDAO agencyDAO;
    
    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(AgencyModelAndView.class);
    
    /**
     * Instantiates a new agency action add language success test.
     */
    public AgencyActionAddLanguageSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Agency action add language succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void agencyActionAddLanguageSucceeds() throws Exception {
        Agency agency = agencyDAO.getAll().get(0);
        AgencyAction action = new AgencyAction(AgencyActionEvent.Operation.AddLanguage,agency.getId());
        this.frontController.handleAction(action);
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        cleanOutOldTestData();
        prepareLoggedInAdminUser();
    }


    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                
                one(viewFactoryService)
                        .processView(
                                with(modelAndViewMatcher));
            }
        });
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @AfterTransaction
    public void verifyModelAndView() throws Exception {
        AgencyModelAndView modelAndView = (AgencyModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(AgencyModelAndView.AgencyViewSpecification.ConfigureAgencyView, modelAndView.getAgencyViewSpecification());
        Assert.assertEquals(AgencyModelAndView.AgencyViewSpecification.ConfigureAgencyView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getAgency());    
        this.cleanOutOldTestData();
    }        
}
