/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.admin;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.context.transaction.BeforeTransaction;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionStatus;
import org.springframework.transaction.support.DefaultTransactionDefinition;

import com.hack23.cia.model.application.impl.admin.LanguageContentActionEvent;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.LanguageContent;
import com.hack23.cia.web.action.admin.LanguageContentAction;
import com.hack23.cia.web.viewfactory.api.admin.LanguageContentModelAndView;

/**
 * The Class LanguageContentActionUpdateSuccessTest.
 */
public class LanguageContentActionUpdateSuccessTest extends
        AbstractFunctionalAdminActionTest {
   
    /** The agency. */
    private Agency agency;

    /** The created language. */
    private Language createdLanguage;
    
    /** The created language content. */
    private LanguageContent createdLanguageContent;
    
    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(LanguageContentModelAndView.class);

    /**
     * Instantiates a new language content action update success test.
     */
    public LanguageContentActionUpdateSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Language content action update succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void languageContentActionUpdateSucceeds() throws Exception {
        createdLanguageContent.setContent(this.testScenarioName);        
        LanguageContentAction action = new LanguageContentAction(LanguageContentActionEvent.Operation.Update, agency,createdLanguageContent);
        this.frontController.handleAction(action);
     }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        cleanOutOldTestData();
        
        TransactionDefinition transactionDefinition = new DefaultTransactionDefinition(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
        
        TransactionStatus transaction = transactionManager.getTransaction(transactionDefinition);
        prepareLoggedInAdminUser();
        createdLanguage = createLanguage();
        
        transactionManager.commit(transaction);

        transaction = transactionManager.getTransaction(transactionDefinition);
        {
            agency = this.adminService.loadAgency();
            createdLanguageContent = createLanguageContent(agency,createdLanguage);
        }
        transactionManager.commit(transaction);
        agency = this.adminService.loadAgency();        
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() {
        context.checking(new Expectations() {
            {
                one(viewFactoryService)
                        .processView(
                                with(modelAndViewMatcher));
            }
        });
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        LanguageContentModelAndView modelAndView = (LanguageContentModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(LanguageContentModelAndView.LanguageContentViewSpecification.ConfigureLanguageContentView, modelAndView.getLanguageContentViewSpecification());
        Assert.assertEquals(LanguageContentModelAndView.LanguageContentViewSpecification.ConfigureLanguageContentView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getLanguageContent());        
    }        

}
