/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.admin;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.application.impl.admin.MonitorActionEvent;
import com.hack23.cia.web.action.admin.MonitorAdminAction;
import com.hack23.cia.web.viewfactory.api.admin.MonitorModelAndView;

/**
 * The Class MonitorAdminShowRecentActionsActionSuccessTest.
 */
public class MonitorAdminShowRecentActionsActionSuccessTest extends
        AbstractFunctionalAdminActionTest {

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(MonitorModelAndView.class);

    /**
     * Instantiates a new monitor admin show recent actions action success test.
     */
    public MonitorAdminShowRecentActionsActionSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        cleanOutOldTestData();
        prepareLoggedInAdminUser();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService)
                        .processView(
                                with(modelAndViewMatcher));
            }
        });        
    }

    /**
     * Show recent actions action succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void showRecentActionsActionSucceeds() throws Exception {
        MonitorAdminAction action = new MonitorAdminAction(
                MonitorActionEvent.Operation.RecentActions);
        this.frontController.handleAction(action);
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        MonitorModelAndView modelAndView = (MonitorModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(MonitorModelAndView.MonitorViewSpecification.RecentActionsView, modelAndView.getMonitorViewSpecification());
        Assert.assertEquals(MonitorModelAndView.MonitorViewSpecification.RecentActionsView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getGraphFilePath());        
    }

}
