/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.admin;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.web.action.admin.TaskAction;
import com.hack23.cia.web.viewfactory.api.admin.TaskModelAndView;

/**
 * The Class TaskActionSuccessTest.
 */
public class TaskActionSuccessTest extends
        AbstractFunctionalAdminActionTest {
    
    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(TaskModelAndView.class);

    /**
     * Instantiates a new task action success test.
     */
    public TaskActionSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        cleanOutOldTestData();
        prepareLoggedInAdminUser();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService)
                        .processView(
                                with(modelAndViewMatcher));
            }
        });
    }

    /**
     * Task action succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void taskActionSucceeds() throws Exception {
        TaskAction action = new TaskAction();
        this.frontController.handleAction(action);
    }


    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        TaskModelAndView modelAndView = (TaskModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(TaskModelAndView.TaskViewSpecification.TaskView, modelAndView.getTaskViewSpecification());
        Assert.assertEquals(TaskModelAndView.TaskViewSpecification.TaskView.toString(), modelAndView.getViewSpecificationDescription());
    }

}
