/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.application;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionStatus;
import org.springframework.transaction.support.DefaultTransactionDefinition;

import com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest;
import com.hack23.cia.model.application.dto.common.ApplicationProperties;
import com.hack23.cia.model.application.dto.common.UserSessionDTO;
import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.model.sweden.impl.Vote.Position;
import com.hack23.cia.service.impl.admin.AdminService;
import com.hack23.cia.web.action.application.ApplicationAction;
import com.hack23.cia.web.viewfactory.api.application.ApplicationModelAndView;

/**
 * The Class ApplicationActionSwedishUserSuccessTest.
 */
public class ApplicationActionSwedishUserSuccessTest extends
        AbstractFunctionalActionWithoutViewFactoryTest {

    /** The admin service. */
    @Autowired
    @Qualifier("adminService")
    protected AdminService adminService;

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(ApplicationModelAndView.class);
    
    /** The transaction manager. */
    @Autowired
    @Qualifier("transactionManager")
    protected PlatformTransactionManager transactionManager;

    /**
     * Instantiates a new application action swedish user success test.
     */
    public ApplicationActionSwedishUserSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Application action swedish user succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void applicationActionSwedishUserSucceeds() throws Exception {
        List<String> argList = new ArrayList<String>();
        argList
                .add("HEADER_USER-AGENT=Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.12) Gecko/2009070811 Ubuntu/9.04 (jaunty) Firefox/3.0.12");
        argList.add("HEADER_ACCEPT-LANGUAGE=xx-xx,xx;q=0.7,sv;q=0.3");
        argList.add("HEADER_COOKIE=JSESSIONID=1ugmg9f4tsmvw");
        argList.add("HEADER_HOST=localhost:9090");
        argList.add("CLIENT_INFO_ADDRESS=0:0:0:0:0:0:0:1");
        argList.add("CLIENT_INFO_HOST=0:0:0:0:0:0:0:1");
        argList.add("CLIENT_INFO_USER=null");

        String[] args = new String[argList.size()];
        argList.toArray(args);

        ApplicationAction action = new ApplicationAction(null, args);
        this.frontController.handleAction(action);
    }

    
    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @Before
    public void setupDatabasePreCondition() throws Exception {
        TransactionDefinition transactionDefinition = new DefaultTransactionDefinition(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
        TransactionStatus transaction = transactionManager.getTransaction(transactionDefinition);
        
        BufferedReader propertyFileUtf8Reader = new BufferedReader(new InputStreamReader
                                (ApplicationProperties.class.getResourceAsStream("/IAResources_sv.properties"),"UTF8"));
        Map<String,String> properties = new HashMap<String,String>();
       
        while(propertyFileUtf8Reader.ready()) {
        	String line = propertyFileUtf8Reader.readLine();
			String[] split = line.split("=");
        	properties.put(split[0], split[1]); 
        }
        propertyFileUtf8Reader.close();
    
        
        Agency agency = this.adminService.loadAgency();
        Language language = agency.findMatchingLanguage("sv");
        for (Object o : properties.keySet()) {
            String key =  (String) o;
            key = key.replace(".", "_").toUpperCase().trim();
    
            Agency.LanguageContentKey contentKey = Agency.LanguageContentKey.valueOf(key);
            
            if (agency.getLanguageContentByKey(key,language) == null) { 
                agency = this.adminService.addAgencyLanguageContent(agency, language, contentKey.toString(), properties.get(o));
            }
        }
        transactionManager.commit(transaction);       
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService).processView(
                        with(modelAndViewMatcher));
            }
        });        
    }
    
    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        ApplicationModelAndView modelAndView = (ApplicationModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        UserSessionDTO userSessionDTO = modelAndView.getUserSessionDTO();
        Assert.assertEquals("Swedish",modelAndView.getUserSessionDTO().getUserSession().getLanguage().getName());        
        
        
        for (Agency.LanguageContentKey key : Agency.LanguageContentKey.values()) {
            Assert.assertNotNull("Missing Swedish Language content for :" + key.toString(), userSessionDTO.getLanguageResource(key));                    
        }
        
        for (Portal.LanguageContentKey key : Portal.LanguageContentKey.values()) {
            Assert.assertNotNull("Missing Swedish Language content for :" + key.toString(), userSessionDTO.getLanguageResource(key));                    
        }
        
        for (Position key : Position.values()) {
            Assert.assertNotNull("Missing Swedish Language content for :" + key.toString(), userSessionDTO.getLanguageResource(key));                    
        }
    }        
}
