/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.user;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.service.dao.BallotDAO;
import com.hack23.cia.web.action.user.BallotAction;
import com.hack23.cia.web.viewfactory.api.user.VotesModelAndView;

/**
 * The Class BallotActionSuccessTest.
 */
public class BallotActionSuccessTest extends
AbstractFunctionalUserActionTest {

    /** The ballot dao. */
    @Autowired
    @Qualifier("ballotDAO")
    protected BallotDAO ballotDAO;

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(VotesModelAndView.class);

    /**
     * Instantiates a new ballot action success test.
     */
    public BallotActionSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Ballot action succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void ballotActionSucceeds() throws Exception {
        Ballot ballot = ballotDAO.getLast();
        BallotAction action = new BallotAction(ballot.getId());
        this.frontController.handleAction(action);

    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.user.AbstractFunctionalUserActionTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        createInitialUserSession();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService).processView(
                        with(modelAndViewMatcher));
            }
        });        
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        VotesModelAndView modelAndView = (VotesModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(VotesModelAndView.VotesViewSpecification.BallotView, modelAndView.getVotesViewSpecification());
        Assert.assertEquals(VotesModelAndView.VotesViewSpecification.BallotView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getVotes());
    }

    
}
