/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.agent.sweden;

import java.util.List;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;

import com.gargoylesoftware.htmlunit.WebClient;
import com.hack23.cia.model.sweden.impl.Ballot;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.model.sweden.impl.Vote;
import com.hack23.cia.service.impl.common.AbstractUnitJmockTest;
import com.hack23.cia.testfoundation.TestInstance;

/**
 * The Class BallotAgentImplTest.
 */
public class BallotAgentImplTest extends AbstractUnitJmockTest {

    /** The ballot agent impl. */
    private BallotAgentImpl ballotAgentImpl;

	/** The web client. */
	private WebClient webClient = new WebClient();

    /**
     * Before test.
     */
    @Before
    public final void beforeTest() {
    	webClient.setActiveXNative(false);
    	webClient.setJavaScriptEnabled(false);
    	webClient.setRedirectEnabled(false);
    	
    	ballotAgentImpl = new BallotAgentImpl(webClient);
    }

    /**
     * Find ballots successfull test.
     */
    @Test
    public final void findBallotsSuccessfullTest() {
        new TestInstance() {

			private CommitteeReport commiteeReport;
			private List<Ballot> findBallots;

			@Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertNotNull(findBallots);
            }

            @Override
            public void run() {
            	try {
            		findBallots = ballotAgentImpl.findBallots(commiteeReport);
				} catch (Exception e) {
					Assert.fail("Not expected Exception: " + e.getMessage());
				}
            }

            @Override
            public void setupExpectations() {
            	commiteeReport = new CommitteeReport();
            	commiteeReport.setHref("http://www.riksdagen.se/webbnav/?nid=3120&doktyp=betankande&bet=2008/09:FiU20");
            }

        }.executeTestPhases();
    }
    
    /**
     * Gets the vote result successfull test.
     *
     * @return the vote result successfull test
     */
    @Test
    public final void getVoteResultSuccessfullTest() {
        new TestInstance() {

			private Ballot ballot;
			private List<Vote> voteResult;

			@Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertNotNull(voteResult);
            }

            @Override
            public void run() {
            	try {
            		voteResult = ballotAgentImpl.getVoteResult(ballot);
				} catch (Exception e) {
					Assert.fail("Not expected Exception: " + e.getMessage());
				}
            }

            @Override
            public void setupExpectations() {
            	ballot = new Ballot();
            	String voteResultsHref="http://www.riksdagen.se/webbnav/index.aspx?nid=3158&guid={C770DCFE-4940-4A95-9785-2F8C7F6750C6}&rm=2008/09";
				ballot.setVoteResultsHref(voteResultsHref);
            }

        }.executeTestPhases();
    }
}
