/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.common;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.Before;
import org.junit.Test;

import com.hack23.cia.model.application.impl.common.User;
import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.dao.AgencyDAO;
import com.hack23.cia.service.dao.UserDAO;
import com.hack23.cia.service.dao.UserSessionDAO;
import com.hack23.cia.testfoundation.TestInstance;

/**
 * The Class UserSessionServiceImplTest.
 */
public class UserSessionServiceImplTest extends AbstractUnitJmockTest {

    /** The mock agency dao. */
    private AgencyDAO mockAgencyDAO = context.mock(AgencyDAO.class);

    /** The mock user dao. */
    private UserDAO mockUserDAO = context.mock(UserDAO.class);

    /** The mock user session dao. */
    private UserSessionDAO mockUserSessionDAO = context
            .mock(UserSessionDAO.class);

    /** The user service impl. */
    private UserSessionServiceImpl userServiceImpl;

    /**
     * Before test.
     */
    @Before
    public final void beforeTest() {
        userServiceImpl = new UserSessionServiceImpl(mockAgencyDAO,
                mockUserDAO, mockUserSessionDAO,null);
    }

    /**
     * Login successfull test.
     */
    @Test
    public final void loginSuccessfullTest() {
        new TestInstance() {

            private final String encodedPassword = "password"; //$NON-NLS-1$

            private final String name = "name"; //$NON-NLS-1$

            private UserSession result;

            private final User user = new User();

            private final UserSession userSession = new UserSession();

            @Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertEquals(userSession, result);
            }

            @Override
            public void run() {
                result = userServiceImpl.login(name, encodedPassword,
                        userSession);
            }

            @Override
            public void setupExpectations() {
                context.checking(new Expectations() {
                    {
                        one(mockUserDAO).getIfValidUser(name, encodedPassword);
                        will(returnValue(user));
                    }
                });
                context.checking(new Expectations() {
                    {
                        one(mockUserSessionDAO).save(userSession);
                        will(returnValue(userSession));
                    }
                });
            }

        }.executeTestPhases();
    }
}
