/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.testfoundation;

import java.sql.Connection;

import javax.sql.DataSource;

import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.transaction.TransactionConfiguration;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionStatus;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.transaction.support.DefaultTransactionDefinition;

import com.hack23.cia.model.application.impl.common.Agency;
import com.hack23.cia.model.application.impl.common.Language;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.service.impl.admin.AdminService;

/**
 * The Class AbstractFunctionalIntegrationTransactionalTest.
 */
@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(loader=MockWebContextLoader.class,locations = {
		"classpath*:/META-INF/cia-application-context-service.xml",
		"classpath*:/META-INF/cia-application-context-web-actionhandlers.xml",
		"classpath*:/META-INF/cia-application-context-web-viewfactories.xml",
		"classpath*:/META-INF/sessionFactory.xml","file:src/main/webapp/WEB-INF/cia-webservices-servlet.xml" })
@TransactionConfiguration(transactionManager = "transactionManager", defaultRollback = false)
@Transactional
public abstract class AbstractFunctionalIntegrationTransactionalTest extends
		AbstractFunctionalIntegrationTest {

	/** The admin service. */
    @Autowired
    @Qualifier("adminService")
    protected AdminService adminService;

    /** The datasource. */
	@Autowired
	private DataSource datasource;
    
    /** The transaction manager. */
    @Autowired
    @Qualifier("transactionManager")
    protected PlatformTransactionManager transactionManager;
	   
   	/**
	    * Clean out old test data.
	    */
    protected final void cleanOutOldTestData() {
        TransactionDefinition transactionDefinition = new DefaultTransactionDefinition(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
        TransactionStatus transaction = transactionManager.getTransaction(transactionDefinition);
     
        Agency agency = this.adminService.loadAgency();
        
        Portal[] portals = new Portal[agency.getPortals().size()];
        for (Portal portal :agency.getPortals().toArray(portals)) {
            if ("Default portal".equals(portal.getName())) {
                this.adminService.deletePortal(portal);
            }
        }
       
        Language[] languages = new Language[agency.getLanguages().size()];        
        for (Language language :agency.getLanguages().toArray(languages)) {
            if ("Default".equalsIgnoreCase(language.getName().trim())) {
                this.adminService.deleteLanguage(agency, language);
            }
        }
        transactionManager.commit(transaction);
    }
    
	/*
	 * (non-Javadoc)
	 * 
	 * @seeorg.directdemocracyportal.democracy.test.fit.
	 * AbstractFunctionalIntegrationTest#getDatabaseConnection()
	 */
	@Override
	protected final Connection getDatabaseConnection() throws Exception {
		return datasource.getConnection();
	}
}
